@@ -471,11 +471,11 @@ asb_context_add_filename (AsbContext *ctx, const gchar *filename, GError **error
 	}
 
 	/* open */
-#if HAVE_RPM
+#ifdef HAVE_RPM
 	if (g_str_has_suffix (filename, ".rpm"))
 		pkg = asb_package_rpm_new ();
 #endif
-#if HAVE_ALPM
+#ifdef HAVE_ALPM
 	if (g_str_has_suffix (filename, ".pkg.tar.xz"))
 		pkg = asb_package_alpm_new ();
 #endif
@@ -929,6 +929,7 @@ asb_context_detect_missing_data (AsbContext *ctx, GError **error)
 		switch (as_app_get_kind (AS_APP (app))) {
 		case AS_APP_KIND_ADDON:
 		case AS_APP_KIND_FIRMWARE:
+		case AS_APP_KIND_DRIVER:
 		case AS_APP_KIND_GENERIC:
 		case AS_APP_KIND_LOCALIZATION:
 			break;
