@@ -51,6 +51,8 @@ G_BEGIN_DECLS
  * @AS_APP_PROBLEM_UPDATECONTACT_FALLBACK:	The file used <updatecontact> without a space
  * @AS_APP_PROBLEM_INVALID_PROJECT_GROUP:	Invalid project group detected
  * @AS_APP_PROBLEM_INVALID_XML_TAG:		Invalid XML tag name detected
+ * @AS_APP_PROBLEM_EXPECTED_CHILDREN:		Children tags expected
+ * @AS_APP_PROBLEM_INVALID_KEYWORDS:		One or more keywords was invalid
  *
  * The application problems detected when loading.
  **/
@@ -71,6 +73,8 @@ typedef enum {
 	AS_APP_PROBLEM_UPDATECONTACT_FALLBACK	= 1 << 12,
 	AS_APP_PROBLEM_INVALID_PROJECT_GROUP	= 1 << 13,
 	AS_APP_PROBLEM_INVALID_XML_TAG		= 1 << 14,
+	AS_APP_PROBLEM_EXPECTED_CHILDREN	= 1 << 15,
+	AS_APP_PROBLEM_INVALID_KEYWORDS		= 1 << 16,
 	/*< private >*/
 	AS_APP_PROBLEM_LAST
 } AsAppProblems;
@@ -79,11 +83,15 @@ typedef enum {
 #define AS_APP_ICON_MIN_HEIGHT			32
 #define AS_APP_ICON_MIN_WIDTH			32
 
+/* unique */
+#define AS_APP_UNIQUE_WILDCARD			"*"
+
 AsAppProblems	 as_app_get_problems		(AsApp		*app);
 guint		 as_app_get_name_size		(AsApp		*app);
 guint		 as_app_get_comment_size	(AsApp		*app);
 guint		 as_app_get_description_size	(AsApp		*app);
 GPtrArray	*as_app_get_search_tokens	(AsApp		*app);
+AsBundleKind	 as_app_get_bundle_kind		(AsApp		*app);
 
 GNode		*as_app_node_insert		(AsApp		*app,
 						 GNode		*parent,
