@@ -129,7 +129,7 @@ typedef enum {
 	AS_APP_SUBSUME_FLAG_NONE		= 0,
 	AS_APP_SUBSUME_FLAG_NO_OVERWRITE	= 1ull << 0,	/* Since: 0.1.4 */
 	AS_APP_SUBSUME_FLAG_BOTH_WAYS		= 1ull << 1,	/* Since: 0.1.4 */
-	AS_APP_SUBSUME_FLAG_PARTIAL		= 1ull << 2,	/* Since: 0.2.2 */
+	AS_APP_SUBSUME_FLAG_REPLACE		= 1ull << 2,	/* Since: 0.6.3 */
 	AS_APP_SUBSUME_FLAG_KIND		= 1ull << 3,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_STATE		= 1ull << 4,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_BUNDLES		= 1ull << 5,	/* Since: 0.6.1 */
@@ -162,6 +162,7 @@ typedef enum {
 	AS_APP_SUBSUME_FLAG_PROJECT_LICENSE	= 1ull << 32,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_PROJECT_GROUP	= 1ull << 33,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_SOURCE_KIND		= 1ull << 34,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_SUGGESTS		= 1ull << 35,	/* Since: 0.6.3 */
 	/*< private >*/
 	AS_APP_SUBSUME_FLAG_LAST,
 } AsAppSubsumeFlags;
@@ -186,9 +187,13 @@ typedef enum {
 					 AS_APP_SUBSUME_FLAG_RELEASES | \
 					 AS_APP_SUBSUME_FLAG_REVIEWS | \
 					 AS_APP_SUBSUME_FLAG_SCREENSHOTS | \
+					 AS_APP_SUBSUME_FLAG_SUGGESTS | \
 					 AS_APP_SUBSUME_FLAG_TRANSLATIONS | \
 					 AS_APP_SUBSUME_FLAG_URL)
 
+/* deprecated name */
+#define AS_APP_SUBSUME_FLAG_PARTIAL	AS_APP_SUBSUME_FLAG_MERGE
+
 /* all properties */
 #define AS_APP_SUBSUME_FLAG_DEDUPE	(AS_APP_SUBSUME_FLAG_BRANCH | \
 					 AS_APP_SUBSUME_FLAG_BUNDLES | \
@@ -291,6 +296,7 @@ typedef enum {
  * @AS_APP_KIND_OS_UPGRADE:		Operating system upgrade
  * @AS_APP_KIND_SHELL_EXTENSION:	GNOME Shell extension
  * @AS_APP_KIND_LOCALIZATION:		Localization data
+ * @AS_APP_KIND_DRIVER:			Driver for hardware support
  *
  * The component type.
  **/
@@ -311,6 +317,7 @@ typedef enum {
 	AS_APP_KIND_SHELL_EXTENSION,	/* Since: 0.5.10 */
 	AS_APP_KIND_LOCALIZATION,	/* Since: 0.5.11 */
 	AS_APP_KIND_CONSOLE,		/* Since: 0.6.1 */
+	AS_APP_KIND_DRIVER,		/* Since: 0.6.3 */
 	/*< private >*/
 	AS_APP_KIND_LAST
 } AsAppKind;
