@@ -1626,9 +1626,9 @@ as_utils_string_replace (GString *string, const gchar *search, const gchar *repl
 {
 	gchar *tmp;
 	guint count = 0;
-	guint search_idx = 0;
-	guint replace_len;
-	guint search_len;
+	gsize search_idx = 0;
+	gsize replace_len;
+	gsize search_len;
 
 	g_return_val_if_fail (string != NULL, 0);
 	g_return_val_if_fail (search != NULL, 0);
@@ -1638,8 +1638,8 @@ as_utils_string_replace (GString *string, const gchar *search, const gchar *repl
 	if (string->len == 0)
 		return 0;
 
-	search_len = (guint) strlen (search);
-	replace_len = (guint) strlen (replace);
+	search_len = strlen (search);
+	replace_len = strlen (replace);
 
 	do {
 		tmp = g_strstr_len (string->str + search_idx, -1, search);
@@ -1647,16 +1647,19 @@ as_utils_string_replace (GString *string, const gchar *search, const gchar *repl
 			break;
 
 		/* advance the counter in case @replace contains @search */
-		search_idx = (guint) (tmp - string->str);
+		search_idx = (gsize) (tmp - string->str);
 
 		/* reallocate the string if required */
 		if (search_len > replace_len) {
-			g_string_erase (string, search_idx,
-					search_len - replace_len);
+			g_string_erase (string,
+					(gssize) search_idx,
+					(gssize) (search_len - replace_len));
 			memcpy (tmp, replace, replace_len);
 		} else if (search_len < replace_len) {
-			g_string_insert_len (string, search_idx, replace,
-					     replace_len - search_len);
+			g_string_insert_len (string,
+					     (gssize) search_idx,
+					     replace,
+					     (gssize) (replace_len - search_len));
 			/* we have to treat this specially as it could have
 			 * been reallocated when the insertion happened */
 			memcpy (string->str + search_idx, replace, replace_len);
@@ -1825,7 +1828,7 @@ as_utils_unique_id_equal (const gchar *unique_id1, const gchar *unique_id2)
 	/* invalid */
 	if (!as_utils_unique_id_valid (unique_id1) ||
 	    !as_utils_unique_id_valid (unique_id2))
-		return FALSE;
+		return g_strcmp0 (unique_id1, unique_id2) == 0;
 
 	/* look at each part */
 	for (i = 0; i < AS_UTILS_UNIQUE_ID_PARTS; i++) {
@@ -1852,3 +1855,44 @@ as_utils_unique_id_equal (const gchar *unique_id1, const gchar *unique_id2)
 	}
 	return TRUE;
 }
+
+/**
+ * as_utils_unique_id_hash:
+ * @unique_id: a unique ID
+ *
+ * Converts a unique-id to a hash value.
+ *
+ * This function implements the widely used DJB hash on the ID subset of the
+ * unique-id string.
+ *
+ * It can be passed to g_hash_table_new() as the hash_func parameter,
+ * when using non-NULL strings or unique_ids as keys in a GHashTable.
+ *
+ * Returns: a hash value corresponding to the key
+ *
+ * Since: 0.6.2
+ */
+guint
+as_utils_unique_id_hash (const gchar *unique_id)
+{
+	gsize i;
+	guint hash = 5381;
+	guint section_cnt = 0;
+
+	/* not a unique ID */
+	if (!as_utils_unique_id_valid (unique_id))
+		return g_str_hash (unique_id);
+
+	/* only include the app-id */
+	for (i = 0; unique_id[i] != '\0'; i++) {
+		if (unique_id[i] == '/') {
+			if (++section_cnt > 4)
+				break;
+			continue;
+		}
+		if (section_cnt < 4)
+			continue;
+		hash = (guint) ((hash << 5) + hash) + (guint) (unique_id[i]);
+	}
+	return hash;
+}
